@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,10 +18,23 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkpush.endpoint import endpoint_data
+
 class QueryTagsRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Push', '2016-08-01', 'QueryTags')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+
+	def get_KeyType(self):
+		return self.get_query_params().get('KeyType')
+
+	def set_KeyType(self,KeyType):
+		self.add_query_param('KeyType',KeyType)
 
 	def get_ClientKey(self):
 		return self.get_query_params().get('ClientKey')
@@ -33,10 +46,4 @@ class QueryTagsRequest(RpcRequest):
 		return self.get_query_params().get('AppKey')
 
 	def set_AppKey(self,AppKey):
-		self.add_query_param('AppKey',AppKey)
-
-	def get_KeyType(self):
-		return self.get_query_params().get('KeyType')
-
-	def set_KeyType(self,KeyType):
-		self.add_query_param('KeyType',KeyType)
\ No newline at end of file
+		self.add_query_param('AppKey',AppKey)
\ No newline at end of file
